@@ -16,11 +16,12 @@ import os
 import re
 import sys
 import errno
+import locale
 import itertools
 import collections
 
 __author__  = 'Miguel Turner'
-__version__ = '0.2.5'
+__version__ = '0.2.6'
 
 __all__ = [
     'Config',
@@ -401,10 +402,7 @@ class ConfigSection(collections.MutableMapping):
         
         # read unchanged values from sources
         for i, source in enumerate(reversed(sources)):
-            try:
-                file = format.open(source)
-            except FileNotFoundError:
-                continue
+            file = format.open(source)
             
             # read file
             try:
@@ -498,7 +496,10 @@ class ConfigSection(collections.MutableMapping):
     def _make_key(self, *path):
         key = []
         sep = self._root.sep
+        encoding = self._root.encoding
         for p in path:
+            if p and isinstance(p, bytes):
+                p = p.decode(encoding)
             if p and isinstance(p, str):
                 key.extend(p.split(sep))
             elif isinstance(p, collections.Sequence):
@@ -594,6 +595,9 @@ class Config(ConfigSection):
     the registered name of a format, such as "ini", or a
     :class:`~profig.Format` class or instance.
     
+    An encoding can be set using *encoding*. If *encoding* is not specified
+    the encoding used is platform dependent: locale.getpreferredencoding(False).
+    
     The dict class used internally can be set using *dict_type*. By default
     an `OrderedDict` is used.
     
@@ -603,20 +607,21 @@ class Config(ConfigSection):
     _formats = {}
     
     def __init__(self, *sources, **kwargs):
-        format = kwargs.pop('format', 'profig')
         self._dict_type = kwargs.pop('dict_type', collections.OrderedDict)
+        super(Config, self).__init__(None, None)
+
+        self.sources = list(sources)
+        self.encoding = kwargs.pop('encoding', locale.getpreferredencoding(False))
+        
+        format = kwargs.pop('format', 'profig')
+        self.set_format(format)
         
         self.coercer = Coercer()
         register_booleans(self.coercer)
-
-        self.sources = list(sources)
-        self.set_format(format)
         
         self.sep = '.'
         self.cache_values = True
         self.coerce_values = True
-        
-        super(Config, self).__init__(None, None)
     
     @classmethod
     def known_formats(cls):
@@ -655,6 +660,7 @@ class Format(BaseFormat):
     def __init__(self, config):
         self.config = config
         
+        self.encoding = config.root.encoding
         self.ensure_dirs = 0o744
         self.read_errors = 'error'
         self.write_errors = 'error'
@@ -676,11 +682,14 @@ class Format(BaseFormat):
         The file object will be truncated.
         This method assumes either read or write/append access, but not both.
         """
+        if isinstance(source, bytes):
+            source = source.decode(self.encoding)
+        
         if isinstance(source, str):
             if self.ensure_dirs is not None and 'w' in mode:
                 # ensure the path exists if any writing is to be done
                 ensure_dirs(os.path.dirname(source), self.ensure_dirs)
-            return open(source, mode, *args)
+            return io.open(source, mode, *args, encoding=self.encoding)
         else:
             source.seek(0)
             if 'w' in mode:
